import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { Assignment } from '../assignments/assignment.model';
import { LoggingService } from './logging.service';

@Injectable({
  providedIn: 'root'
})
export class AssignmentsService {
  assignments:Assignment[] = [
    {
      id:1,
      nom: 'Devoir WebComponents Buffa',
      dateDeRendu: new Date('2021-11-15'),
      rendu: false,
    },
    {
      id:2,
      nom: 'Devoir Angular Buffa',
      dateDeRendu: new Date('2021-12-18'),
      rendu: false,
    },
    {
      id:3,
      nom: 'Devoir Greg Galli gRails',
      dateDeRendu: new Date('2021-10-20'),
      rendu: true,
    },
  ];

  constructor(private loggingService:LoggingService) { }

  getAssignments():Observable<Assignment[]> {
    // typiquement, on ferait une requête GET sur un web
    // service distant, pour récupérer les assignments
    // et cela pourrait prendre quelques secondes...
    return of(this.assignments);
  }

  getAssignment(id:number):Observable<Assignment|undefined> {

    const a:Assignment|undefined = this.assignments.find(elem => elem.id == id);

    return of(a);
  }

  addAssigment(assignment:Assignment):Observable<string> {
    // typiquement, plus tard, au lieu de faire un push, on fera une requête
    // vers un service distant
    assignment.id = Math.floor(10000000 * Math.random());

    this.assignments.push(assignment);

    //console.log("Assignment ajouté");
    this.loggingService.log(assignment.nom, "AJOUTE")

    return of("Assignment " + assignment.nom + " ajouté");
  }

  updateAssignment(assignment:Assignment):Observable<string> {
    // Ici plus tard requête distante sur web service en PUT

    // avec le tableau, comme l'assignment est un pointeur sur une case, on a rien besoin
    // de faire....
    return of("Assignment " + assignment.nom + " modifié");
  }
  deleteAssignment(assignment:Assignment) :Observable<string>{
    // on supprime cet assignment
    const pos = this.assignments.indexOf(assignment);
    this.assignments.splice(pos, 1);
    return of("Assignment " + assignment.nom + " supprimé");
  }
}
